@@ -145,7 +145,9 @@ class UserResponderMixin(object):
             if self.flash_unverified_user:
                 message, category = self.flash_unverified_user
                 flash(message.format(user.email), category)
-        if not user.is_enabled:
+                return  # preventing unverified users to also get the disabled alert
+
+        if not user.is_active:
             self.on_disabled_user(user)
 
     def on_invalid_user(self, username):
@@ -831,7 +833,9 @@ class KegAuthenticator(PasswordAuthenticatorMixin, LoginAuthenticator):
             # apply a domain filter before looking up the user record
             raise UserNotFound
 
-        user = self.user_ent.query.filter_by(username=login_id).one_or_none()
+        user = self.user_ent.query.filter(
+            sa.func.lower(self.user_ent.username) == (login_id.lower() if login_id else None)
+        ).one_or_none()
 
         if not user:
             raise UserNotFound
