@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 
 from datetime import timedelta
 from unittest import mock
-from urllib.parse import quote, urlparse
+from urllib.parse import quote
 
 import arrow
 import flask
@@ -17,20 +17,26 @@ from keg import current_app
 
 from keg_auth.libs.authenticators import AttemptLimitMixin
 
-try:
-    has_attempt_model = flask.current_app.auth_manager.entity_registry.is_registered('attempt')
-except RuntimeError as exc:
-    if 'application context' not in str(exc):
-        raise
-    has_attempt_model = False
-
 has_attempt_skip_reason = 'no attempt model registered in entity registry'
 
 
+def has_attempt_model():
+    try:
+        return flask.current_app.auth_manager.entity_registry.is_registered('attempt')
+    except RuntimeError as exc:
+        if 'application context' not in str(exc):
+            raise
+    return False
+
+
 class AuthAttemptTests(object):
     """Tests to verify that automated attempt logging/blocking works as intended. These
     tests are included in the AuthTests class and are intended to be used in target
     applications to verify customization hasn't broken basic KegAuth functionality."""
+    login_url = None
+    forgot_password_url = None
+    reset_password_url = None
+
     forgot_invalid_flashes = [('error', 'No user account matches: foo@bar.com')]
     forgot_lockout_flashes = [('error', 'Too many failed attempts.')]
     forgot_success_flashes = [
@@ -59,8 +65,7 @@ class AuthAttemptTests(object):
         cls.bundle_ent = flask.current_app.auth_manager.entity_registry.bundle_cls
 
     def do_login(self, client, email, password, submit_status=200):
-        login_url = flask.url_for(flask.current_app.auth_manager.endpoint('login'))
-        resp = client.get(login_url)
+        resp = client.get(self.login_url)
         resp.form['login_id'] = email
         resp.form['password'] = password
         return resp.form.submit(status=submit_status)
@@ -74,7 +79,6 @@ class AuthAttemptTests(object):
             resp = self.do_login(client or self.client, username, password, submit_status)
             assert resp.flashes == flashes
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @pytest.mark.parametrize('limit, timespan, lockout', [
         (3, 3600, 7200),
         (3, 7200, 300),
@@ -94,12 +98,19 @@ class AuthAttemptTests(object):
         limit. Login attempts after the lockout period has passed (since the failed attempt
         that caused the lockout) should not be blocked.
         '''
-        config_key = 'LOGIN_' if view_config else ''
-        with mock.patch.dict('flask.current_app.config', {
-            f'KEGAUTH_{config_key}ATTEMPT_LIMIT': limit,
-            f'KEGAUTH_{config_key}ATTEMPT_TIMESPAN': timespan,
-            f'KEGAUTH_{config_key}ATTEMPT_LOCKOUT': lockout,
-        }):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
+        config_key = lambda flag: 'LOGIN_' if flag else ''
+        config_updates = lambda flag: {
+            f'KEGAUTH_{config_key(flag)}ATTEMPT_LIMIT': limit,
+            f'KEGAUTH_{config_key(flag)}ATTEMPT_TIMESPAN': timespan,
+            f'KEGAUTH_{config_key(flag)}ATTEMPT_LOCKOUT': lockout,
+        }
+        with mock.patch.dict('flask.current_app.config', config_updates(view_config)):
+            for key in config_updates(not view_config):
+                if key in flask.current_app.config:
+                    del flask.current_app.config[key]
+
             # We want to test blocking attempts for existing and non-existing users.
             username = 'foo@bar.com'
             invalid_flashes = [('error', 'No user account matches: foo@bar.com')]
@@ -167,7 +178,6 @@ class AuthAttemptTests(object):
             assert_attempt_count(limit + 1, fail_count)
             assert_attempt_count(limit + 1, limit + 1, is_during_lockout=True)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @mock.patch.dict('flask.current_app.config', {
         'KEGAUTH_ATTEMPT_LIMIT_ENABLED': False,
         'KEGAUTH_LOGIN_ATTEMPT_LIMIT': 3,
@@ -178,6 +188,8 @@ class AuthAttemptTests(object):
         '''
         Test that we do not block any attempts with missing attempt entity.
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
         assert self.attempt_ent.query.count() == 0
 
@@ -205,7 +217,6 @@ class AuthAttemptTests(object):
         with pytest.raises(Exception, match=r'.*attempt entity is not registered.*'):
             self.do_login(self.client, user.email, 'badpass', 200)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @pytest.mark.parametrize('limit, timespan, lockout', [
         (3, 3600, 7200),
         (3, 7200, 300),
@@ -216,6 +227,8 @@ class AuthAttemptTests(object):
         Test that several failed logins before a successful login do not count
         towards the attempt lockout counter.
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         with mock.patch.dict('flask.current_app.config', {
             'KEGAUTH_LOGIN_ATTEMPT_LIMIT': limit,
             'KEGAUTH_LOGIN_ATTEMPT_TIMESPAN': timespan,
@@ -250,7 +263,6 @@ class AuthAttemptTests(object):
             # after the successful attempt.
             do_test(login_time + timedelta(seconds=limit + 1), self.login_lockout_flashes)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @pytest.mark.parametrize('limit, timespan, lockout', [
         (3, 3600, 7200),
     ])
@@ -258,6 +270,8 @@ class AuthAttemptTests(object):
         '''
         Test that login attempts get blocked for an IP address
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         client = flask_webtest.TestApp(flask.current_app,
                                        extra_environ={'REMOTE_ADDR': '192.168.0.111'})
 
@@ -307,8 +321,7 @@ class AuthAttemptTests(object):
                     client=self.client)
 
     def do_forgot(self, client, email, submit_status=200):
-        forgot_url = flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password'))
-        resp = client.get(forgot_url)
+        resp = client.get(self.forgot_password_url)
         resp.form['email'] = email
         return resp.form.submit(status=submit_status)
 
@@ -320,7 +333,6 @@ class AuthAttemptTests(object):
             resp = self.do_forgot(self.client, username, submit_status)
             assert resp.flashes == flashes
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @pytest.mark.parametrize('limit, timespan, lockout', [
         (3, 3600, 7200),
         (3, 7200, 300),
@@ -332,6 +344,8 @@ class AuthAttemptTests(object):
         limit. forgot attempts after the lockout period has passed (since the failed attempt
         that caused the lockout) should not be blocked.
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         with mock.patch.dict('flask.current_app.config', {
             'KEGAUTH_FORGOT_ATTEMPT_LIMIT': limit,
             'KEGAUTH_FORGOT_ATTEMPT_TIMESPAN': timespan,
@@ -400,7 +414,6 @@ class AuthAttemptTests(object):
             assert_attempt_count(limit + 1, fail_count)
             assert_attempt_count(limit + 1, limit + 1, is_during_lockout=True)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @mock.patch.dict('flask.current_app.config', {
         'KEGAUTH_ATTEMPT_LIMIT_ENABLED': False,
         'KEGAUTH_FORGOT_ATTEMPT_LIMIT': 3,
@@ -411,6 +424,8 @@ class AuthAttemptTests(object):
         '''
         Test that we do not block any attempts with missing attempt entity.
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         assert self.attempt_ent.query.count() == 0
 
         def do_test(attempt_count, flashes, submit_status=200):
@@ -422,7 +437,6 @@ class AuthAttemptTests(object):
         do_test(0, self.forgot_invalid_flashes)
         do_test(0, self.forgot_invalid_flashes)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @pytest.mark.parametrize('limit, timespan, lockout', [
         (3, 3600, 7200),
         (3, 7200, 300),
@@ -433,6 +447,8 @@ class AuthAttemptTests(object):
         Test that several failed forgots before a successful forgot do not count
         towards the attempt lockout counter.
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         with mock.patch.dict('flask.current_app.config', {
             'KEGAUTH_FORGOT_ATTEMPT_LIMIT': limit,
             'KEGAUTH_FORGOT_ATTEMPT_TIMESPAN': timespan,
@@ -473,8 +489,7 @@ class AuthAttemptTests(object):
             return_value=reset_time,
         ):
             token = user.token_generate()
-            url = flask.url_for(flask.current_app.auth_manager.endpoint('reset-password'),
-                                user_id=user.id, token=token)
+            url = self.reset_password_url.format(user_id=user.id, token=token)
             resp = self.client.get(url, status=200)
             new_pass = randchars(8)
             resp.form['password'] = new_pass
@@ -482,7 +497,6 @@ class AuthAttemptTests(object):
             resp = resp.form.submit(status=submit_status)
             assert resp.flashes == flashes
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @pytest.mark.parametrize('limit, timespan, lockout', [
         (3, 3600, 7200),
         (3, 7200, 300),
@@ -494,6 +508,8 @@ class AuthAttemptTests(object):
         limit. Login attempts after the lockout period has passed (since the failed attempt
         that caused the lockout) should not be blocked.
         '''
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         with mock.patch.dict('flask.current_app.config', {
             'KEGAUTH_RESET_ATTEMPT_LIMIT': limit,
             'KEGAUTH_RESET_ATTEMPT_TIMESPAN': timespan,
@@ -556,7 +572,6 @@ class AuthAttemptTests(object):
             assert_attempt_count(limit + 1, 0)
             assert_attempt_count(limit + 1, limit + 1, is_during_lockout=True)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @mock.patch.dict('flask.current_app.config', {
         'KEGAUTH_ATTEMPT_LIMIT_ENABLED': False,
         'KEGAUTH_RESET_ATTEMPT_LIMIT': 2,
@@ -564,6 +579,8 @@ class AuthAttemptTests(object):
         'KEGAUTH_RESET_ATTEMPT_LOCKOUT': 7200,
     })
     def test_reset_pw_attempts_not_blocked(self):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         user = self.user_ent.testing_create()
         assert self.attempt_ent.query.count() == 0
 
@@ -575,17 +592,19 @@ class AuthAttemptTests(object):
         do_test(arrow.utcnow(), self.reset_success_flashes, 302)
         do_test(arrow.utcnow(), self.reset_success_flashes, 302)
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     @mock.patch('keg_auth.libs.authenticators.AttemptLimitMixin.get_request_remote_addr',
                 return_value='12.12.12.12')
     def test_logs_attempt_source_ip(self, m_get_remote_addr):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
         self.do_login(self.client, user.email, 'pass', 302)
 
         assert self.attempt_ent.query.one().source_ip == m_get_remote_addr.return_value
 
-    @pytest.mark.skipif(not has_attempt_model, reason=has_attempt_skip_reason)
     def test_get_request_remote_addr(self):
+        if not has_attempt_model():
+            pytest.skip(has_attempt_skip_reason)
         with current_app.test_request_context(environ_base={'REMOTE_ADDR': '12.12.12.12'}):
             assert AttemptLimitMixin.get_request_remote_addr() == '12.12.12.12'
 
@@ -595,6 +614,12 @@ class AuthTests(AuthAttemptTests):
         These tests are designed so they can can be imported into an application's tests
         and ran to ensure customization of KegAuth hasn't broken basic functionality.
     """
+    login_url = '/login'
+    forgot_password_url = '/forgot-password'
+    reset_password_url = '/reset-password/{user_id}/{token}'
+    after_login_url = '/'
+    logout_url = '/logout'
+    after_logout_url = login_url
     protected_url = '/secret1'
     protected_url_permissions = None
 
@@ -605,19 +630,16 @@ class AuthTests(AuthAttemptTests):
     def test_login_get(self):
         app = flask.current_app
         client = flask_webtest.TestApp(app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
         assert resp.status_code == 200
 
     def test_login_head(self):
         client = flask_webtest.TestApp(flask.current_app)
-        client.head(
-            flask.url_for(flask.current_app.auth_manager.endpoint('login')),
-            status=405,
-        )
+        client.head(self.login_url, status=405)
 
     def test_login_form_error(self):
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
 
         resp.form['login_id'] = 'foo'
         resp = resp.form.submit(status=200)
@@ -632,16 +654,14 @@ class AuthTests(AuthAttemptTests):
         user = self.user_ent.testing_create(email='foo@bar.com', password='pass')
 
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'pass'
         resp = resp.form.submit()
 
         assert resp.status_code == 302, resp.html
-        assert resp.headers['Location'] == flask.url_for(
-            flask.current_app.auth_manager.endpoint('after-login')
-        )
+        assert resp.headers['Location'] == self.after_login_url
         flash_success = flask.current_app.auth_manager.login_authenticator_cls.responder_cls['login'].flash_success  # noqa
         category = flash_success[1]
         message = flash_success[0]
@@ -660,16 +680,14 @@ class AuthTests(AuthAttemptTests):
 
         next = '/foo'
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get('{}?next={}'.format(
-            flask.url_for(flask.current_app.auth_manager.endpoint('login')), next)
-        )
+        resp = client.get('{}?next={}'.format(self.login_url, next))
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'pass'
         resp = resp.form.submit()
 
         assert resp.status_code == 302, resp.html
-        assert resp.headers['Location'] == 'http://keg.example.com{}'.format(next)
+        assert resp.headers['Location'] == next
         flash_success = flask.current_app.auth_manager.login_authenticator_cls.responder_cls['login'].flash_success  # noqa
         category = flash_success[1]
         message = flash_success[0]
@@ -683,14 +701,14 @@ class AuthTests(AuthAttemptTests):
             client = flask_webtest.TestApp(flask.current_app)
             with client.session_transaction() as sess:
                 sess['next'] = next
-            resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+            resp = client.get(self.login_url)
 
             resp.form['login_id'] = 'foo@bar.com'
             resp.form['password'] = 'pass'
             resp = resp.form.submit()
 
         assert resp.status_code == 302, resp.html
-        assert resp.headers['Location'] == 'http://keg.example.com{}'.format(next)
+        assert resp.headers['Location'] == next
         flash_success = flask.current_app.auth_manager.login_authenticator_cls.responder_cls['login'].flash_success  # noqa
         category = flash_success[1]
         message = flash_success[0]
@@ -703,10 +721,7 @@ class AuthTests(AuthAttemptTests):
         # unquoted next parameter
         next = 'http://www.example.com'
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get('{}?next={}'.format(
-            flask.url_for(flask.current_app.auth_manager.endpoint('login')), next
-            )
-        )
+        resp = client.get('{}?next={}'.format(self.login_url, next))
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'pass'
@@ -714,9 +729,7 @@ class AuthTests(AuthAttemptTests):
 
         assert resp.status_code == 302, resp.html
         # verify the 'next' parameter was ignored
-        assert resp.headers['Location'] == flask.url_for(
-            flask.current_app.auth_manager.endpoint('after-login')
-        )
+        assert resp.headers['Location'] == self.after_login_url
         flash_success = flask.current_app.auth_manager.login_authenticator_cls.responder_cls['login'].flash_success  # noqa
         category = flash_success[1]
         message = flash_success[0]
@@ -724,12 +737,7 @@ class AuthTests(AuthAttemptTests):
 
         # quoted next parameter
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(
-            '{}?next={}'.format(
-                flask.url_for(flask.current_app.auth_manager.endpoint('login')),
-                quote(next)
-            )
-        )
+        resp = client.get('{}?next={}'.format(self.login_url, quote(next)))
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'pass'
@@ -737,9 +745,7 @@ class AuthTests(AuthAttemptTests):
 
         assert resp.status_code == 302, resp.html
         # verify the 'next' parameter was ignored
-        assert resp.headers['Location'] == flask.url_for(
-            flask.current_app.auth_manager.endpoint('after-login')
-        )
+        assert resp.headers['Location'] == self.after_login_url
         flash_success = flask.current_app.auth_manager.login_authenticator_cls.responder_cls['login'].flash_success  # noqa
         category = flash_success[1]
         message = flash_success[0]
@@ -751,7 +757,7 @@ class AuthTests(AuthAttemptTests):
             assert self.attempt_ent.query.count() == 0
 
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'badpass'
@@ -773,7 +779,7 @@ class AuthTests(AuthAttemptTests):
 
     def test_login_user_missing(self):
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'badpass'
@@ -789,7 +795,7 @@ class AuthTests(AuthAttemptTests):
         self.user_ent.testing_create(email='foo@bar.com', password='pass', is_verified=False)
 
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'badpass'
@@ -805,7 +811,7 @@ class AuthTests(AuthAttemptTests):
         self.user_ent.testing_create(email='foo@bar.com', password='pass', is_enabled=False)
 
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('login')))
+        resp = client.get(self.login_url)
 
         resp.form['login_id'] = 'foo@bar.com'
         resp.form['password'] = 'badpass'
@@ -817,6 +823,26 @@ class AuthTests(AuthAttemptTests):
         message = flash_disabled_user[0]
         assert resp.flashes == [(category, message.format('foo@bar.com'))]
 
+    def test_login_user_disabled_timestamp(self):
+        self.user_ent.testing_create(
+            email='foo@bar.com',
+            password='pass',
+            disabled_utc=arrow.utcnow().shift(days=-10)
+        )
+
+        client = flask_webtest.TestApp(flask.current_app)
+        resp = client.get(self.login_url)
+
+        resp.form['login_id'] = 'foo@bar.com'
+        resp.form['password'] = 'badpass'
+        resp = resp.form.submit(status=200)
+
+        flash_disabled_user = flask.current_app.auth_manager.login_authenticator_cls. \
+            responder_cls['login'].flash_disabled_user
+        category = flash_disabled_user[1]
+        message = flash_disabled_user[0]
+        assert resp.flashes == [(category, message.format('foo@bar.com'))]
+
     def test_login_protection(self):
         self.user_ent.testing_create(
             email='foo@bar.com', password='pass', permissions=self.protected_url_permissions
@@ -824,10 +850,7 @@ class AuthTests(AuthAttemptTests):
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(self.protected_url, status=302)
-        full_login_url = 'http://keg.example.com{}'.format(
-            urlparse(flask.url_for(flask.current_app.auth_manager.endpoint('login'))).path
-        )
-        assert resp.headers['Location'].startswith(full_login_url)
+        assert resp.headers['Location'].startswith(self.login_url)
 
         resp = resp.follow()
         resp.form['login_id'] = 'foo@bar.com'
@@ -843,7 +866,7 @@ class AuthTests(AuthAttemptTests):
 
     def test_forgot_pw_form_error(self):
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password')))
+        resp = client.get(self.forgot_password_url)
         resp = resp.form.submit(status=200)
 
         flash_form_error = flask.current_app.auth_manager.login_authenticator_cls.\
@@ -854,7 +877,7 @@ class AuthTests(AuthAttemptTests):
 
     def test_forgot_pw_invalid_user(self):
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password')))
+        resp = client.get(self.forgot_password_url)
 
         resp.form['email'] = 'foo@bar.com'
         resp = resp.form.submit(status=200)
@@ -869,7 +892,7 @@ class AuthTests(AuthAttemptTests):
         self.user_ent.testing_create(email='foo@bar.com', password='pass', is_enabled=False)
 
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password')))
+        resp = client.get(self.forgot_password_url)
 
         resp.form['email'] = 'foo@bar.com'
         resp = resp.form.submit(status=200)
@@ -884,7 +907,7 @@ class AuthTests(AuthAttemptTests):
         self.user_ent.testing_create(email='foo@bar.com')
 
         client = flask_webtest.TestApp(flask.current_app)
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password')))
+        resp = client.get(self.forgot_password_url)
 
         resp.form['email'] = 'foo@bar.com'
         resp = resp.form.submit(status=302)
@@ -895,18 +918,14 @@ class AuthTests(AuthAttemptTests):
         message = flash_success[0]
         assert resp.flashes == [(category, message)]
 
-        full_login_url = 'http://keg.example.com{}'.format(
-            urlparse(flask.url_for(flask.current_app.auth_manager.endpoint('login'))).path
-        )
-        assert resp.headers['Location'] == full_login_url
+        assert resp.headers['Location'] == self.login_url
 
     def test_reset_pw_success(self):
         user = self.user_ent.testing_create()
         if has_attempt_model:
             assert self.attempt_ent.query.count() == 0
         token = user.token_generate()
-        url = flask.url_for(flask.current_app.auth_manager.endpoint('reset-password'),
-                            user_id=user.id, token=token)
+        url = self.reset_password_url.format(user_id=user.id, token=token)
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(url, status=200)
@@ -921,10 +940,7 @@ class AuthTests(AuthAttemptTests):
         message = flash_success[0]
         assert resp.flashes == [(category, message)]
 
-        full_login_url = 'http://keg.example.com{}'.format(
-            urlparse(flask.url_for(flask.current_app.auth_manager.endpoint('login'))).path
-        )
-        assert resp.headers['Location'] == full_login_url
+        assert resp.headers['Location'] == self.login_url
         if has_attempt_model:
             assert self.attempt_ent.query.count() == 1
             assert self.attempt_ent.get_by(attempt_type='reset', user_input=user.email)
@@ -932,8 +948,7 @@ class AuthTests(AuthAttemptTests):
     def test_reset_pw_form_error(self):
         user = self.user_ent.testing_create()
         token = user.token_generate()
-        url = flask.url_for(flask.current_app.auth_manager.endpoint('reset-password'),
-                            user_id=user.id, token=token)
+        url = self.reset_password_url.format(user_id=user.id, token=token)
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(url, status=200)
@@ -946,16 +961,14 @@ class AuthTests(AuthAttemptTests):
         assert resp.flashes == [(category, message)]
 
     def test_reset_pw_missing_user(self):
-        url = flask.url_for(flask.current_app.auth_manager.endpoint('reset-password'),
-                            user_id='99999999', token='123')
+        url = self.reset_password_url.format(user_id='99999999', token='123')
 
         client = flask_webtest.TestApp(flask.current_app)
         client.get(url, status=404)
 
     def test_reset_pw_bad_token(self):
         user = self.user_ent.testing_create()
-        url = flask.url_for(flask.current_app.auth_manager.endpoint('reset-password'),
-                            user_id=user.id, token='abc')
+        url = url = self.reset_password_url.format(user_id=user.id, token='abc')
 
         client = flask_webtest.TestApp(flask.current_app)
         resp = client.get(url, status=302)
@@ -966,10 +979,7 @@ class AuthTests(AuthAttemptTests):
         message = flash_invalid_token[0]
         assert resp.flashes == [(category, message)]
 
-        full_forgot_password_url = 'http://keg.example.com{}'.format(
-            urlparse(flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password'))).path
-        )
-        assert resp.headers['Location'] == full_forgot_password_url
+        assert resp.headers['Location'] == self.forgot_password_url
 
     def test_verify_account_success(self):
         user = self.user_ent.testing_create(is_verified=False)
@@ -991,10 +1001,7 @@ class AuthTests(AuthAttemptTests):
         message = flash_success[0]
         assert resp.flashes == [(category, message)]
 
-        full_login_url = 'http://keg.example.com{}'.format(
-            urlparse(flask.url_for(flask.current_app.auth_manager.endpoint('login'))).path
-        )
-        assert resp.headers['Location'] == full_login_url
+        assert resp.headers['Location'] == self.login_url
 
         assert user.is_verified
 
@@ -1034,10 +1041,7 @@ class AuthTests(AuthAttemptTests):
         message = flash_invalid_token[0]
         assert resp.flashes == [(category, message)]
 
-        full_forgot_password_url = 'http://keg.example.com{}'.format(
-            urlparse(flask.url_for(flask.current_app.auth_manager.endpoint('forgot-password'))).path
-        )
-        assert resp.headers['Location'] == full_forgot_password_url
+        assert resp.headers['Location'] == self.forgot_password_url
 
     def test_logout(self):
         user = self.user_ent.testing_create(permissions=self.protected_url_permissions)
@@ -1049,14 +1053,11 @@ class AuthTests(AuthAttemptTests):
         client.get(self.protected_url, status=200)
 
         # logout
-        resp = client.get(flask.url_for(flask.current_app.auth_manager.endpoint('logout')),
-                          status=302)
+        resp = client.get(self.logout_url, status=302)
         assert resp.flashes == [('success', 'You have been logged out.')]
 
         # Check redirect location
-        full_after_logout_url = flask.url_for(flask.current_app.auth_manager.
-                                              endpoint('after-logout'))
-        assert resp.headers['Location'] == full_after_logout_url
+        assert resp.headers['Location'] == self.after_logout_url
 
         # Confirm logout occured
         client.get(self.protected_url, status=302)
